==> qtjambi-test-debuginfo-windows-x64-5.15.18.jar: sources/QtJambiTest/QTestDelayEvent_shell.cpp <==
#include "QTestDelayEvent_shell.h"
#include <QtJambi/Cast>

void deleter_QTestDelayEvent(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QTestDelayEvent")
    QTestDelayEvent *_ptr = reinterpret_cast<QTestDelayEvent *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QTestDelayEvent_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QTestDelayEvent_shell) ); }

jmethodID QTestDelayEvent_shell::__shell_javaMethod(int pos) const { return QTestDelayEvent_shell::__shell()->javaMethod(typeid(QTestDelayEvent), pos); }

// emitting (writeShellConstructor)
QTestDelayEvent_shell::QTestDelayEvent_shell(int msecs0)
    : QTestDelayEvent(msecs0)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QTestDelayEvent::QTestDelayEvent_shell(int msecs0)", QTestDelayEvent_shell::__shell())
    QTestDelayEvent_shell::__shell()->constructed(typeid(QTestDelayEvent));
}

// emitting (writeShellDestructor)
QTestDelayEvent_shell::~QTestDelayEvent_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QTestDelayEvent::~QTestDelayEvent()", QTestDelayEvent_shell::__shell())
    QTestDelayEvent_shell::__shell()->destructed(typeid(QTestDelayEvent));
}

void QTestDelayEvent_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QTestDelayEvent_shell*>(ptr)->QTestDelayEvent_shell::__shell()->tryDeleteShell(typeid(QTestDelayEvent));
}

// emitting Virtual overrides (virtualFunctions)
QTestEvent* QTestDelayEvent_shell::clone() const
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QTestDelayEvent::clone()const", QTestDelayEvent_shell::__shell())
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QTestEvent*  __qt_return_value = nullptr;
            QTJAMBI_TRY {
                if(jobject __java_this = QTestDelayEvent_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_return_value = __jni_env->CallObjectMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = qtjambi_cast<QTestEvent* >(__jni_env, __java_return_value);
                    QtJambiAPI::setCppOwnership(__jni_env, __java_return_value);
                } else {
                    QTestDelayEvent_shell::__shell()->warnForMethod("QTestDelayEvent::clone()const");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QTestDelayEvent::clone()const");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QTestDelayEvent::clone();
        }
    }else{
        return QTestDelayEvent::clone();
    }
}

void QTestDelayEvent_shell::simulate(QWidget* arg__1)
{
    if(jmethodID method_id = __shell_javaMethod(1)){
        QTJAMBI_JAVA_METHOD_CALL("QTestDelayEvent::simulate(QWidget*)", QTestDelayEvent_shell::__shell())
        if(JniEnvironment __jni_env{300}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QTJAMBI_TRY {
                if(jobject __java_this = QTestDelayEvent_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_arg__1 = qtjambi_cast<jobject>(__jni_env, arg__1);
                    QTJAMBI_INVALIDATE_AFTER_USE(__jni_env, __java_arg__1);
                    __jni_env->CallVoidMethod(__java_this, method_id, __java_arg__1);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                } else {
                    QTestDelayEvent_shell::__shell()->warnForMethod("QTestDelayEvent::simulate(QWidget*)");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QTestDelayEvent::simulate(QWidget*)");
            } QTJAMBI_TRY_END
        }else{
            QTestDelayEvent::simulate(arg__1);
        }
    }else{
        QTestDelayEvent::simulate(arg__1);
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
jobject QTestDelayEvent_access::__qt_clone(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        QTestEvent* __qt_return_value = QTestDelayEvent::clone();
        jobject __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnership(__jni_env, __java_return_value);
        return __java_return_value;
    } else {
        QTestEvent* __qt_return_value = clone();
        jobject __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnership(__jni_env, __java_return_value);
        return __java_return_value;
    }
}

void QTestDelayEvent_access::__qt_simulate_QWidget_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1)
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    QWidget* __qt_arg__1 = QtJambiAPI::objectFromNativeId<QWidget>(arg__1);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        QTestDelayEvent::simulate(__qt_arg__1);
    } else {
        simulate(__qt_arg__1);
    }
}

// emitting (writeConstructors)
// new QTestDelayEvent(int)
void __qt_construct_QTestDelayEvent_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QTestDelayEvent(int)")
    jint msecs0 = __java_arguments[0].i;
    Q_UNUSED(msecs0)
    QTestDelayEvent *__qt_this = new(__qtjambi_ptr) QTestDelayEvent_shell(static_cast<int>(msecs0));
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QTestDelayEvent_shell
void __qt_destruct_QTestDelayEvent(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QTestDelayEvent")
    reinterpret_cast<QTestDelayEvent_shell*>(ptr)->~QTestDelayEvent_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QTestDelayEvent::QTestDelayEvent(int)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_test_QTestDelayEvent_initialize_1native__Lio_qt_test_QTestDelayEvent_2I)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jint msecs0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QTestDelayEvent::QTestDelayEvent(int)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.i = msecs0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QTestDelayEvent_0, sizeof(QTestDelayEvent_shell), typeid(QTestDelayEvent), true, &deleter_QTestDelayEvent, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QTestDelayEvent::clone()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_test_QTestDelayEvent_clone_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QTestDelayEvent *__qt_this = QtJambiAPI::objectFromNativeId<QTestDelayEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QTestDelayEvent::clone()const", __qt_this)
        __java_return_value = static_cast<const QTestDelayEvent_access*>(__qt_this)->__qt_clone(__jni_env, __this_nativeId);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QTestDelayEvent::simulate(QWidget*)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_test_QTestDelayEvent_simulate_1native_1QWidget_1ptr__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID arg__1)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QTestDelayEvent *__qt_this = QtJambiAPI::objectFromNativeId<QTestDelayEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QTestDelayEvent::simulate(QWidget*)", __qt_this)
        static_cast<QTestDelayEvent_access*>(__qt_this)->__qt_simulate_QWidget_ptr(__jni_env, __this_nativeId, arg__1);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QTestDelayEvent(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QTestDelayEvent>("QTestDelayEvent", "io/qt/test/QTestDelayEvent");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "clone", "()Lio/qt/test/QTestEvent;"),
        FunctionInfo(/* 1 */ "simulate", "(Lio/qt/widgets/QWidget;)V")});
    registerConstructorInfos(typeId, &__qt_destruct_QTestDelayEvent, {
        ConstructorInfo(&__qt_construct_QTestDelayEvent_0, "I")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QTestDelayEvent);
    registerSizeOfShell(typeId, sizeof(QTestDelayEvent_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QTestEvent, QTestDelayEvent>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-test-debuginfo-windows-x64-6.7.0.jar: sources/QtJambiTest/QTestDelayEvent_shell.cpp <==
#include "QTestDelayEvent_shell.h"
#include <QtJambi/Cast>

void deleter_QTestDelayEvent(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QTestDelayEvent")
    QTestDelayEvent *_ptr = reinterpret_cast<QTestDelayEvent *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QTestDelayEvent_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QTestDelayEvent_shell) ); }

jmethodID QTestDelayEvent_shell::__shell_javaMethod(int pos) const { return QTestDelayEvent_shell::__shell()->javaMethod(typeid(QTestDelayEvent), pos); }

// emitting (writeShellConstructor)
QTestDelayEvent_shell::QTestDelayEvent_shell(int msecs0)
    : QTestDelayEvent(msecs0)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QTestDelayEvent::QTestDelayEvent_shell(int msecs0)", QTestDelayEvent_shell::__shell())
    QTestDelayEvent_shell::__shell()->constructed(typeid(QTestDelayEvent));
}

// emitting (writeShellDestructor)
QTestDelayEvent_shell::~QTestDelayEvent_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QTestDelayEvent::~QTestDelayEvent()", QTestDelayEvent_shell::__shell())
    QTestDelayEvent_shell::__shell()->destructed(typeid(QTestDelayEvent));
}

void QTestDelayEvent_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QTestDelayEvent_shell*>(ptr)->QTestDelayEvent_shell::__shell()->tryDeleteShell(typeid(QTestDelayEvent));
}

// emitting Virtual overrides (virtualFunctions)
QTestEvent* QTestDelayEvent_shell::clone() const
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QTestDelayEvent::clone()const", QTestDelayEvent_shell::__shell())
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QTestEvent*  __qt_return_value = nullptr;
            QTJAMBI_TRY {
                if(jobject __java_this = QTestDelayEvent_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_return_value = __jni_env->CallObjectMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = qtjambi_cast<QTestEvent* >(__jni_env, __java_return_value);
                    QtJambiAPI::setCppOwnership(__jni_env, __java_return_value);
                } else {
                    QTestDelayEvent_shell::__shell()->warnForMethod("QTestDelayEvent::clone()const");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QTestDelayEvent::clone()const");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QTestDelayEvent::clone();
        }
    }else{
        return QTestDelayEvent::clone();
    }
}

void QTestDelayEvent_shell::simulate(QWidget* arg__1)
{
    if(jmethodID method_id = __shell_javaMethod(1)){
        QTJAMBI_JAVA_METHOD_CALL("QTestDelayEvent::simulate(QWidget*)", QTestDelayEvent_shell::__shell())
        if(JniEnvironment __jni_env{300}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QTJAMBI_TRY {
                if(jobject __java_this = QTestDelayEvent_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_arg__1 = qtjambi_cast<jobject>(__jni_env, arg__1);
                    QTJAMBI_INVALIDATE_AFTER_USE(__jni_env, __java_arg__1);
                    __jni_env->CallVoidMethod(__java_this, method_id, __java_arg__1);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                } else {
                    QTestDelayEvent_shell::__shell()->warnForMethod("QTestDelayEvent::simulate(QWidget*)");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QTestDelayEvent::simulate(QWidget*)");
            } QTJAMBI_TRY_END
        }else{
            QTestDelayEvent::simulate(arg__1);
        }
    }else{
        QTestDelayEvent::simulate(arg__1);
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
jobject QTestDelayEvent_access::__qt_clone_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        QTestEvent* __qt_return_value = QTestDelayEvent::clone();
        jobject __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnership(__jni_env, __java_return_value);
        return __java_return_value;
    } else {
        QTestEvent* __qt_return_value = clone();
        jobject __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnership(__jni_env, __java_return_value);
        return __java_return_value;
    }
}

void QTestDelayEvent_access::__qt_simulate_QWidget_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1)
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    QWidget* __qt_arg__1 = QtJambiAPI::objectFromNativeId<QWidget>(arg__1);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        QTestDelayEvent::simulate(__qt_arg__1);
    } else {
        simulate(__qt_arg__1);
    }
}

// emitting (writeConstructors)
// new QTestDelayEvent(int)
void __qt_construct_QTestDelayEvent_int(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QTestDelayEvent(int)")
    jint msecs0 = __java_arguments[0].i;
    Q_UNUSED(msecs0)
    QTestDelayEvent *__qt_this = new(__qtjambi_ptr) QTestDelayEvent_shell(static_cast<int>(msecs0));
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QTestDelayEvent::QTestDelayEvent(int)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_test_QTestDelayEvent_initialize_1native__Lio_qt_test_QTestDelayEvent_2I)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jint msecs0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QTestDelayEvent::QTestDelayEvent(int)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.i = msecs0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QTestDelayEvent_int, sizeof(QTestDelayEvent_shell), typeid(QTestDelayEvent), true, &deleter_QTestDelayEvent, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QTestDelayEvent_shell
void __qt_destruct_QTestDelayEvent(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QTestDelayEvent")
    reinterpret_cast<QTestDelayEvent_shell*>(ptr)->~QTestDelayEvent_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QTestDelayEvent::clone()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_test_QTestDelayEvent_clone_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QTestDelayEvent *__qt_this = QtJambiAPI::objectFromNativeId<QTestDelayEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QTestDelayEvent::clone()const", __qt_this)
        __java_return_value = static_cast<const QTestDelayEvent_access*>(__qt_this)->__qt_clone_constfct(__jni_env, __this_nativeId);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QTestDelayEvent::simulate(QWidget*)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_test_QTestDelayEvent_simulate_1native_1QWidget_1ptr__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID arg__1)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QTestDelayEvent *__qt_this = QtJambiAPI::objectFromNativeId<QTestDelayEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QTestDelayEvent::simulate(QWidget*)", __qt_this)
        static_cast<QTestDelayEvent_access*>(__qt_this)->__qt_simulate_QWidget_ptr(__jni_env, __this_nativeId, arg__1);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QTestDelayEvent(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QTestDelayEvent>("QTestDelayEvent", "io/qt/test/QTestDelayEvent");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "clone", "()Lio/qt/test/QTestEvent;"),
        FunctionInfo(/* 1 */ "simulate", "(Lio/qt/widgets/QWidget;)V")});
    registerConstructorInfos(typeId, &__qt_destruct_QTestDelayEvent, {
        ConstructorInfo(&__qt_construct_QTestDelayEvent_int, "I")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QTestDelayEvent);
    registerSizeOfShell(typeId, sizeof(QTestDelayEvent_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QTestEvent, QTestDelayEvent>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
